quantizationtools.QGrid
=======================

.. abjad-lineage:: abjad.tools.quantizationtools.QGrid.QGrid

.. autoclass:: abjad.tools.quantizationtools.QGrid.QGrid

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.QGrid.QGrid.distance
      ~abjad.tools.quantizationtools.QGrid.QGrid.fit_q_events
      ~abjad.tools.quantizationtools.QGrid.QGrid.leaves
      ~abjad.tools.quantizationtools.QGrid.QGrid.next_downbeat
      ~abjad.tools.quantizationtools.QGrid.QGrid.offsets
      ~abjad.tools.quantizationtools.QGrid.QGrid.pretty_rtm_format
      ~abjad.tools.quantizationtools.QGrid.QGrid.root_node
      ~abjad.tools.quantizationtools.QGrid.QGrid.rtm_format
      ~abjad.tools.quantizationtools.QGrid.QGrid.sort_q_events_by_index
      ~abjad.tools.quantizationtools.QGrid.QGrid.subdivide_leaf
      ~abjad.tools.quantizationtools.QGrid.QGrid.subdivide_leaves
      ~abjad.tools.quantizationtools.QGrid.QGrid.__call__
      ~abjad.tools.quantizationtools.QGrid.QGrid.__copy__
      ~abjad.tools.quantizationtools.QGrid.QGrid.__eq__
      ~abjad.tools.quantizationtools.QGrid.QGrid.__format__
      ~abjad.tools.quantizationtools.QGrid.QGrid.__hash__
      ~abjad.tools.quantizationtools.QGrid.QGrid.__ne__
      ~abjad.tools.quantizationtools.QGrid.QGrid.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.distance
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.leaves
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.next_downbeat
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.offsets
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.pretty_rtm_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.root_node
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGrid.QGrid.rtm_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.fit_q_events
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.sort_q_events_by_index
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.subdivide_leaf
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.subdivide_leaves
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.__copy__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.__hash__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGrid.QGrid.__repr__
   :noindex:
